@@ -94,7 +94,7 @@ SECTION_DESC = {
         "Colors used in the UI.\n"
         "A value can be in one of the following format:\n\n"
         " * `#RGB`/`#RRGGBB`/`#RRRGGGBBB`/`#RRRRGGGGBBBB`\n"
-        " * A SVG color name as specified in http://www.w3.org/TR/SVG/"
+        " * An SVG color name as specified in http://www.w3.org/TR/SVG/"
         "types.html#ColorKeywords[the W3C specification].\n"
         " * transparent (no color)\n"
         " * `rgb(r, g, b)` / `rgba(r, g, b, a)` (values 0-255 or "
@@ -134,11 +134,6 @@ def data(readonly=False):
              SettingValue(typ.IgnoreCase(), 'smart'),
              "Whether to find text on a page case-insensitively."),
 
-            ('wrap-search',
-             SettingValue(typ.Bool(), 'true'),
-             "Whether to wrap finding text to the top when arriving at the "
-             "end."),
-
             ('startpage',
              SettingValue(typ.List(), 'https://duckduckgo.com'),
              "The default page(s) to open at the start, separated by commas."),
@@ -272,6 +267,10 @@ def data(readonly=False):
              SettingValue(typ.VerticalPosition(), 'top'),
              "Where to show the downloaded files."),
 
+            ('status-position',
+             SettingValue(typ.VerticalPosition(), 'bottom'),
+             "The position of the status bar."),
+
             ('message-timeout',
              SettingValue(typ.Int(), '2000'),
              "Time (in ms) to show messages in the statusbar for."),
@@ -284,10 +283,6 @@ def data(readonly=False):
              SettingValue(typ.ConfirmQuit(), 'never'),
              "Whether to confirm quitting the application."),
 
-            ('display-statusbar-messages',
-             SettingValue(typ.Bool(), 'false'),
-             "Whether to display javascript statusbar messages."),
-
             ('zoom-text-only',
              SettingValue(typ.Bool(), 'false'),
              "Whether the zoom factor on a frame applies only to the text or "
@@ -330,7 +325,7 @@ def data(readonly=False):
             ('window-title-format',
              SettingValue(typ.FormatString(fields=['perc', 'perc_raw', 'title',
                                                    'title_sep', 'id',
-                                                   'scroll_pos']),
+                                                   'scroll_pos', 'host']),
                           '{perc}{title}{title_sep}qutebrowser'),
              "The format to use for the window title. The following "
              "placeholders are defined:\n\n"
@@ -340,7 +335,8 @@ def data(readonly=False):
              "* `{title_sep}`: The string ` - ` if a title is set, empty "
              "otherwise.\n"
              "* `{id}`: The internal window ID of this window.\n"
-             "* `{scroll_pos}`: The page scroll position."),
+             "* `{scroll_pos}`: The page scroll position.\n"
+             "* `{host}`: The host of the current web page."),
 
             ('hide-mouse-cursor',
              SettingValue(typ.Bool(), 'false'),
@@ -627,7 +623,7 @@ def data(readonly=False):
             ('title-format',
              SettingValue(typ.FormatString(
                  fields=['perc', 'perc_raw', 'title', 'title_sep', 'index',
-                         'id', 'scroll_pos']), '{index}: {title}'),
+                         'id', 'scroll_pos', 'host']), '{index}: {title}'),
              "The format to use for the tab title. The following placeholders "
              "are defined:\n\n"
              "* `{perc}`: The percentage as a string like `[10%]`.\n"
@@ -637,7 +633,8 @@ def data(readonly=False):
              "otherwise.\n"
              "* `{index}`: The index of this tab.\n"
              "* `{id}`: The internal tab ID of this tab.\n"
-             "* `{scroll_pos}`: The page scroll position."),
+             "* `{scroll_pos}`: The page scroll position.\n"
+             "* `{host}`: The host of the current web page."),
 
             ('title-alignment',
              SettingValue(typ.TextAlignment(), 'left'),
@@ -886,7 +883,7 @@ def data(readonly=False):
             ('chars',
              SettingValue(typ.UniqueCharString(minlen=2, completions=[
                  ('asdfghjkl', "Home row"),
-                 ('dhtnaoeu', "Home row (Dvorak)"),
+                 ('aoeuidnths', "Home row (Dvorak)"),
                  ('abcdefghijklmnopqrstuvwxyz', "All letters"),
              ]), 'asdfghjkl'),
              "Chars used for hint strings."),
@@ -1461,15 +1458,14 @@ KEY_DATA = collections.OrderedDict([
         ('hint all hover', [';h']),
         ('hint images', [';i']),
         ('hint images tab', [';I']),
-        ('hint images tab-bg', ['.i']),
         ('hint links fill ":open {hint-url}"', [';o']),
         ('hint links fill ":open -t {hint-url}"', [';O']),
-        ('hint links fill ":open -b {hint-url}"', ['.o']),
         ('hint links yank', [';y']),
         ('hint links yank-primary', [';Y']),
         ('hint --rapid links tab-bg', [';r']),
         ('hint --rapid links window', [';R']),
         ('hint links download', [';d']),
+        ('hint inputs', [';t']),
         ('scroll left', ['h']),
         ('scroll down', ['j']),
         ('scroll up', ['k']),
@@ -1548,6 +1544,7 @@ KEY_DATA = collections.OrderedDict([
         ('open qute:settings', ['Ss']),
         ('follow-selected', RETURN_KEYS),
         ('follow-selected -t', ['<Ctrl-Return>', '<Ctrl-Enter>']),
+        ('repeat-command', ['.']),
     ])),
 
     ('insert', collections.OrderedDict([
@@ -1577,6 +1574,7 @@ KEY_DATA = collections.OrderedDict([
         ('prompt-accept', RETURN_KEYS),
         ('prompt-yes', ['y']),
         ('prompt-no', ['n']),
+        ('prompt-open-download', ['<Ctrl-X>']),
     ])),
 
     ('command,prompt', collections.OrderedDict([
